==> tur-dupelog_1.0.tar.gz: tur-dupelog.sh <==
#!/bin/sh
VER=1.0
#--------------------------------------------------------------------#
# Tur-Dupelog by Turranius ( http://www.grandis.nu/glftpd/ )         #
#--------------------------------------------------------------------#
# This script will build a new dupelog based on the sections you     #
# specify. It will not go deeper then those sections, so CD1 and     #
# such crap will not be included in the new one.                     #
# It will always copy the old dirlog to dirlog.old.                  #
#                                                                    #
#-[ Prelude ]--------------------------------------------------------#
# This is the main part of the script. You need to edit this to set  #
# what it should log to.                                             #
#                                                                    #
#-[ Installation ]---------------------------------------------------#
# Put this script together with tur-dupelogdata.sh and make them     #
# both executable. Once you have it working like you want, crontab   #
# it to run as often as you like.                                    #
# The first time though, it should be run without any arguments.     #
#                                                                    #
# Set the following setting.                                         #
#                                                                    #
# DUPELOG=   Full path of your dupelog.                              #
#                                                                    #
# OLDFIRST=  Which order do you want your dupelog in?                #
#            TRUE =  Oldest releases first.                          #
#            FALSE = Newest releases first.                          #
#                                                                    #
# If you havent already, edit tur-dupelogdate.sh too.                #
#                                                                    #
#-[ Note ] ----------------------------------------------------------#
# Run this script without arguments for usage and explanation.       #
#                                                                    #
#-[ Contact ]--------------------------------------------------------#        
# Contact me on Efnet (Turranius / Turran / Turr|away / Turr|work)   #
#                                                                    #
#-[ Settings ]-------------------------------------------------------#

DUPELOG="/glftpd/ftp-data/logs/dupelog"
OLDFIRST="TRUE"

################################################################################
# No changes needed below here, unless your name is soehest and you run fbsd   #
################################################################################

if [ -e $DUPELOG ]; then
  FOUND="OK"
else
  echo "Can not find existing dupelog, $DUPELOG."
  echo "Please fix this."
  exit 0
fi

if [ "$OLDFIRST" = "TRUE" ]; then
  SORTORDER="sort"
else
  SORTORDER="sort -r"
fi

if [ "$1" = "" ]; then
  echo "#-------------[ Tur-DupeLog $VER by Turranius ]--------------"
  echo "#"
  echo "# Options are: "
  echo "# test  =  Show the would-be dupelog on screen"
  echo "# go    =  Backup the old dupelog to .old and create a new one"
  echo "# "
  echo "#-------------------------------------------------------------"
  exit 0
fi

if [ "$1" = "test" ]; then
  echo "Test mode enabled. Please wait while I check the defined sections."
  echo "This may take a while, depending on number of folders"
  tur-dupelogdata.sh | $SORTORDER
  exit 0
fi

if [ "$1" = "go" ]; then
  cp -f $DUPELOG $DUPELOG.old
  tur-dupelogdata.sh | $SORTORDER > $DUPELOG
  exit 0
fi


echo "hmm. Nonono. Run this without any arguments for explanation!"
exit 0

==> tur-dupelog_1.1.tar.gz: tur-dupelog.sh <==
#!/bin/sh
VER=1.0
#--------------------------------------------------------------------#
# Tur-Dupelog by Turranius ( http://www.grandis.nu/glftpd/ )         #
#--------------------------------------------------------------------#
# This script will build a new dupelog based on the sections you     #
# specify. It will not go deeper then those sections, so CD1 and     #
# such crap will not be included in the new one.                     #
# It will always copy the old dirlog to dirlog.old.                  #
#                                                                    #
#-[ Prelude ]--------------------------------------------------------#
# This is the main part of the script. You need to edit this to set  #
# what it should log to.                                             #
#                                                                    #
#-[ Installation ]---------------------------------------------------#
# Put this script together with tur-dupelogdata.sh and make them     #
# both executable. Once you have it working like you want, crontab   #
# it to run as often as you like.                                    #
# The first time though, it should be run without any arguments.     #
#                                                                    #
# Set the following setting.                                         #
#                                                                    #
# DUPELOG=   Full path of your dupelog.                              #
#                                                                    #
# OLDFIRST=  Which order do you want your dupelog in?                #
#            TRUE =  Oldest releases first.                          #
#            FALSE = Newest releases first.                          #
#                                                                    #
# If you havent already, edit tur-dupelogdate.sh too.                #
#                                                                    #
#-[ Note ] ----------------------------------------------------------#
# Run this script without arguments for usage and explanation.       #
#                                                                    #
#-[ Contact ]--------------------------------------------------------#        
# Contact me on Efnet (Turranius / Turran / Turr|away / Turr|work)   #
#                                                                    #
#-[ Settings ]-------------------------------------------------------#

DUPELOG="/glftpd/ftp-data/logs/dupelog"
OLDFIRST="TRUE"

################################################################################
# No changes needed below here, unless your name is soehest and you run fbsd   #
################################################################################

if [ -e $DUPELOG ]; then
  FOUND="OK"
else
  echo "Can not find existing dupelog, $DUPELOG."
  echo "Please fix this."
  exit 0
fi

if [ "$OLDFIRST" = "TRUE" ]; then
  SORTORDER="sort"
else
  SORTORDER="sort -r"
fi

if [ "$1" = "" ]; then
  echo "#-------------[ Tur-DupeLog $VER by Turranius ]--------------"
  echo "#"
  echo "# Options are: "
  echo "# test  =  Show the would-be dupelog on screen"
  echo "# go    =  Backup the old dupelog to .old and create a new one"
  echo "# "
  echo "#-------------------------------------------------------------"
  exit 0
fi

if [ "$1" = "test" ]; then
  echo "Test mode enabled. Please wait while I check the defined sections."
  echo "This may take a while, depending on number of folders"
  echo "Dated folders take a longer time"
  ./tur-dupelogdata.sh test | $SORTORDER
  exit 0
fi

if [ "$1" = "go" ]; then
  cp -f $DUPELOG $DUPELOG.old
  ./tur-dupelogdata.sh | $SORTORDER > $DUPELOG
  exit 0
fi


echo "hmm. Nonono. Run this without any arguments for explanation!"
exit 0
